@@ -309,25 +309,52 @@ if (Sentry === undefined) {
     };
 
     $(document).ready(function(){
-        $('.filter-list').each(function(_, el){
-            var $el = $(el);
-            if ($el.find('li').length > 6) {
-                // rebuild this widget as a dropdown select
-                var select = $('<select></select>');
-                var parent = $('<div class="filter-select sidebar-module">').appendTo($el.parent());
+        // replace selects with inline select2 widgets
+        $('.filter select').select2({
+            allowClear: true
+        }).on('change', function(e){
+            var query = Sentry.getQueryParams();
+            query[e.target.name] = e.val;
+            window.location.href = '?' + $.param(query);
+        });
 
-                $el.find('li a').each(function(_, a){
-                    a = $(a);
-                    var opt = $('<option value="' + a.attr('href') + '">' + a.text() + '</option>').appendTo(select);
-                    if (a.parent().hasClass('active')) {
-                        opt.attr('selected', 'selected');
+        // replace text inputs with remote select2 widgets
+        $('.filter input[type=text]').each(function(_, el){
+            var $el = $(el);
+            $el.select2({
+                initSelection: function (el, callback) {
+                    var $el = $(el);
+                    callback({id: $el.val(), text: $el.val()});
+                },
+                allowClear: true,
+                minimumInputLength: 3,
+                ajax: {
+                    url: Sentry.options.urlPrefix + '/api/' + Sentry.options.projectId + '/tags/search/',
+                    dataType: 'json',
+                    data: function (term, page) {
+                        return {
+                            query: term,
+                            quietMillis: 300,
+                            name: $el.attr('name'),
+                            limit: 10
+                        };
+                    },
+                    results: function (data, page) {
+                        var results = [];
+                        $(data.results).each(function(_, val){
+                            results.push({
+                                id: val,
+                                text: val
+                            });
+                        });
+                        return {results: results};
                     }
-                });
-                $el.remove();
-                select.appendTo(parent).change(function(){
-                    window.location.href = $(this).val();
-                });
-            }
+                }
+            });
+        }).on('change', function(e){
+            var query = Sentry.getQueryParams();
+            query[e.target.name] = e.val;
+            window.location.href = '?' + $.param(query);
         });
 
         // Update date strings periodically
